@@ -5,7 +5,7 @@ use warnings;
 package Switcheroo;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006';
+our $VERSION   = '0.007';
 our @EXPORT    = qw( switch );
 our @EXPORT_OK = qw( match );
 our @ISA       = qw( Exporter::Tiny );
@@ -27,6 +27,7 @@ sub import
 sub switch
 {
 	my ($pkg, $expr, $comparator, $cases, $default) = @_;
+	
 	my @args = @_ = caller_args(1);
 	
 	my $pad = peek_my(1);
@@ -62,10 +63,11 @@ sub switch
 		}
 		else
 		{
-			TERM: for my $term (@$condition)
+			TERM: for my $termexpr (@$condition)
 			{
-				lexalias($term, $_, $pad->{$_}) for keys %$pad;
-				$match->($var, $term->()) ? (++$matched && last TERM) : next TERM;
+				lexalias($termexpr, $_, $pad->{$_}) for keys %$pad;
+				my $term = $termexpr->(@args);
+				$match->($var, $term) ? (++$matched && last TERM) : next TERM;
 			}
 		}
 		
